@@ -22,7 +22,7 @@ use itertools::Itertools;
 use num::traits::Pow;
 
 use crate::client::physics::speed::Speed;
-use crate::client::state::local::inventory::{PlayerInventory, ItemStack};
+use crate::client::state::local::inventory::PlayerInventory;
 use crate::protocol::Face;
 use crate::storage::block::{BlockApprox, BlockKind, BlockLocation, BlockState, SimpleType};
 use crate::storage::blocks::WorldBlocks;
@@ -333,9 +333,8 @@ impl Physics {
                 None => {
                     eprintln!("tried to place air");
                     self.pending.place = None;
-                },
+                }
             };
-
         }
 
 
